==> social-project-1.1.8-source-release.zip: social-project-1.1.8/component/core/src/main/java/org/exoplatform/social/core/processor/OSHtmlSanitizerProcessor.java <==
/*
 * Copyright (C) 2003-2010 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.social.core.processor;

import org.exoplatform.container.PortalContainer;
import org.exoplatform.container.xml.InitParams;
import org.exoplatform.social.common.xmlprocessor.XMLProcessor;
import org.exoplatform.social.core.BaseActivityProcessorPlugin;
import org.exoplatform.social.core.activity.model.Activity;

public class OSHtmlSanitizerProcessor extends BaseActivityProcessorPlugin {

  private XMLProcessor xmlProcessor;

  public OSHtmlSanitizerProcessor(InitParams params) {
    super(params);
  }

  public void processActivity(Activity activity) {
    if (xmlProcessor == null) {
      xmlProcessor = (XMLProcessor) PortalContainer.getInstance().getComponentInstanceOfType(XMLProcessor.class);
    }
    activity.setTitle((String) xmlProcessor.process(activity.getTitle()));
    activity.setBody((String) xmlProcessor.process(activity.getBody()));
  }

}

==> social-project-1.1.10-source-release.zip: social-project-1.1.10/component/core/src/main/java/org/exoplatform/social/core/processor/OSHtmlSanitizerProcessor.java <==
/*
 * Copyright (C) 2003-2010 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.social.core.processor;

import java.util.List;
import java.util.Map;

import org.exoplatform.container.PortalContainer;
import org.exoplatform.container.xml.InitParams;
import org.exoplatform.social.common.xmlprocessor.XMLProcessor;
import org.exoplatform.social.core.BaseActivityProcessorPlugin;
import org.exoplatform.social.core.activity.model.Activity;

public class OSHtmlSanitizerProcessor extends BaseActivityProcessorPlugin {

  private XMLProcessor xmlProcessor;

  public OSHtmlSanitizerProcessor(InitParams params) {
    super(params);
  }

  public void processActivity(Activity activity) {
    if (xmlProcessor == null) {
      xmlProcessor = (XMLProcessor) PortalContainer.getInstance().getComponentInstanceOfType(XMLProcessor.class);
    }
    activity.setTitle((String) xmlProcessor.process(activity.getTitle()));
    activity.setBody((String) xmlProcessor.process(activity.getBody()));

    Map<String, String> templateParams = activity.getTemplateParams();
    
    List<String> templateParamKeys = getTemplateParamKeysToProcess(activity);
    for(String key : templateParamKeys){
      templateParams.put(key, (String) xmlProcessor.process(templateParams.get(key)));
    }
  }

}
